summaryrefslogtreecommitdiffstats
path: root/base/nss_util.cc
diff options
context:
space:
mode:
Diffstat (limited to 'base/nss_util.cc')
-rw-r--r--base/nss_util.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/base/nss_util.cc b/base/nss_util.cc
index 5c7cafd..b144881 100644
--- a/base/nss_util.cc
+++ b/base/nss_util.cc
@@ -230,10 +230,10 @@ class NSSInitSingleton {
SECStatus status = NSS_Shutdown();
if (status != SECSuccess) {
- // We VLOG(1) because this failure is relatively harmless (leaking, but
- // we're shutting down anyway).
- VLOG(1) << "NSS_Shutdown failed; see "
- "http://code.google.com/p/chromium/issues/detail?id=4609";
+ // We LOG(INFO) because this failure is relatively harmless
+ // (leaking, but we're shutting down anyway).
+ LOG(INFO) << "NSS_Shutdown failed; see "
+ "http://code.google.com/p/chromium/issues/detail?id=4609";
}
}